@@ -9,9 +9,10 @@ use integer;
 
 use Carp;
 use List::Util qw(all);
-use Scalar::Util::Numeric qw(isint);
 
-our $VERSION = '0.0106'; # VERSION
+use vars qw ($VERSION);
+
+$VERSION = '0.01';
 
 use Config;
 BEGIN {
@@ -45,13 +46,13 @@ sub new {
     if ( my $ref_of_key = ref( $key ) ) {
         croak( sprintf( 'key must be a %d-byte-long STRING or a reference of ARRAY', $KEY_SIZE ) ) if not $ref_of_key eq 'ARRAY';
         croak( sprintf( 'key must has %d elements if key is a reference of ARRAY', $ELEMENTS_IN_KEY ) ) if scalar( @{ $key } ) != $ELEMENTS_IN_KEY;
-        croak( 'each element of key must be a 32bit Integer if key is a reference of ARRAY' ) if not all { isint( $_ ) != 0 } @{ $key };
+        croak( 'each element of key must be a NUMBER if key is a reference of ARRAY' ) if not all { /^-?\d+$/ } @{ $key };
         $xtea_key = $key;
     } else {
         croak( sprintf( 'key must be a %d-byte-long STRING or a reference of ARRAY', $KEY_SIZE ) ) if length $key != $KEY_SIZE;
         $xtea_key = key_setup($key);
     }
-    croak( 'rounds must be a positive NUMBER' ) if isint( $rounds ) != 1;
+    croak( 'rounds must be a positive NUMBER' ) if $rounds !~ /^\d+$/;
     my $self = {
         key => $xtea_key,
         rounds => $rounds,
@@ -63,7 +64,7 @@ sub new {
 sub encrypt {
     my $self = shift;
     my $plain_text = shift;
-    croak( sprintf( 'plain_text size must be %d bytes', $BLOCK_SIZE) ) if length($plain_text) != $BLOCK_SIZE;
+    croak( sprintf( 'block size must be %d', $BLOCK_SIZE) ) if length($plain_text) != $BLOCK_SIZE;
     my @block = unpack 'N*', $plain_text;
     my $cipher_text_ref = $self->encrypt_block( \@block );
     return pack( 'N*', @{$cipher_text_ref} );
@@ -73,7 +74,7 @@ sub encrypt {
 sub decrypt {
     my $self = shift;
     my $cipher_text = shift;
-    croak( sprintf( 'cipher_text size must be %d bytes', $BLOCK_SIZE) ) if length($cipher_text) != $BLOCK_SIZE;
+    croak( sprintf( 'block size must be %d', $BLOCK_SIZE) ) if length($cipher_text) != $BLOCK_SIZE;
     my @block = unpack 'N*', $cipher_text;
     my $plain_text_ref = $self->decrypt_block( \@block );
     return pack( 'N*', @{$plain_text_ref} );
@@ -126,8 +127,8 @@ sub decrypt_block {
 sub key_setup {
     my $key_str = shift;
     croak( sprintf( 'key must be %s bytes long', $KEY_SIZE ) ) if length( $key_str ) != $KEY_SIZE;
-    my @xtea_key = unpack 'N*', $key_str;
-    return \@xtea_key;
+    my @tea_key = unpack 'N*', $key_str;
+    return \@tea_key;
 }
 
 
@@ -145,7 +146,7 @@ Crypt::XTEA_PP - Pure Perl Implementation of the eXtended Tiny Encryption Algori
 
 =head1 VERSION
 
-version 0.0106
+version 0.0301
 
 =head1 SYNOPSIS
 
